.. Packaging Scientific Python documentation master file, created by
   sphinx-quickstart on Thu Jun 28 12:35:56 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

==================
GGCE Documentation
==================

.. toctree::
   :hidden:

   overview
   installation
   tutorials
   modules
   project

The Generalized Green's Cluster Function Expansion (GGCE) is a numerically exact generalization of the Momentum Average family of methods used for solving electron-phonon Hamiltonians in the single-electron sector (the polaron limit). For a pedagogical introduction to Momentum Average methods, we recommend reading the `work of Mona Berciu <https://phas.ubc.ca/~berciu/PAPERS/papers.html>`__, specifically that of `Berciu and Fehske, PRB 82, 085116 (2010) <https://journals.aps.org/prb/abstract/10.1103/PhysRevB.82.085116>`__. The GGCE method itself is based off of `Carbone, Reichman & Sous, PRB 104, 035106 (2021) <https://journals.aps.org/prb/abstract/10.1103/PhysRevB.104.035106>`__.
